import 'package:workouttest_util/model/exercise_ability.dart';
import 'package:workouttest_util/util/app_language.dart';
import 'package:workouttest_util/util/enums.dart';
import 'package:flutter/material.dart';

class ExerciseType {
  ///exerciseTypeId
  late int exerciseTypeId;

  /// name
  late String name;

  /// description
  late String description;

  /// unit
  late String unit;

  /// unitQuantity
  String? unitQuantity;

  /// unitQuantityUnit
  String? unitQuantityUnit;

  ///active
  late bool active;

  /// base
  late bool base;

  late bool buddyWarning;

  /// imageUrl
  String imageUrl = "";

  /// nameTranslation
  String nameTranslation = "";

  /// descriptionTranslation
  String descriptionTranslation = "";

  /// devices[]
  List<int> devices = [];

  /// parents[]
  List<int> parents = [];

  /// alternatives []
  List<int> alternatives = [];

  /// ability
  ExerciseAbility? ability;

  /// TrainingPlanState - whether the exercise_type exists in the
  /// custom training plan
  ExerciseTypeTrainingPlanState trainingPlanState = ExerciseTypeTrainingPlanState.none;

  ExerciseType({required name, required description});

  ExerciseType.fromJson(Map json) {
    exerciseTypeId = json['exerciseTypeId'];
    //treeId = json['treeId'];
    name = json['name'];
    description = json['description'];
    unit = json['unit'];
    unitQuantity = json['unitQuantity'];
    unitQuantityUnit = json['unitQuantityUnit'];
    active = json['active'];
    base = json['base'];
    buddyWarning = json['buddyWarning'];
    if (json['images'].length > 0) {
      imageUrl = json['images'][0]['url'];
    }
    if (json['translations'].length > 0) {
      nameTranslation = AppLanguage().appLocal == const Locale('hu') ? json['translations'][0]['name'] : json['name'];
      descriptionTranslation = AppLanguage().appLocal == const Locale('hu') ? json['translations'][0]['description'] : json['description'];
    }

    if (json['devices'].length > 0) {
      final List jsonDevices = json['devices'];

      for (var device in jsonDevices) {
        devices.add(device['exerciseDeviceId']);
      }
    }

    if (json['parents'].length > 0) {
      final List jsonParents = json['parents'];

      for (var parent in jsonParents) {
        parents.add(parent['exerciseTreeId']);
      }
    }

    if (json['alternatives'].length > 0) {
      final List jsonAlternatives = json['alternatives'];

      for (var alternative in jsonAlternatives) {
        alternatives.add(alternative['exerciseTypeChildId']);
      }
    }
  }

  Map<String, dynamic> toJson() => {
        "name": name,
        "description": description,
        "unit": unit,
        "unitQuantity": unitQuantity,
        "unitQuantityUnit": unitQuantityUnit,
        "active": active,
        "base": base,
        "buddyWarning": buddyWarning,
        "devices": devices.toString(),
        "nameTranslation": nameTranslation,
        "parents": parents.toString()
      };

  void setAbility(ExerciseAbility ability) {
    ability = ability;
  }

  ExerciseAbility getAbility() {
    return ability!;
  }

  bool is1RM() {
    return ability!.equalsTo(ExerciseAbility.oneRepMax);
  }

  @override
  String toString() {
    return toJson().toString();
  }
}
